==> mpf-0.51.2-cp34-none-any.whl: mpf/core/mode_device.py <==
"""Contains a class to implement mode devices."""
import abc
import asyncio

from typing import Generator

from mpf.core.device import Device
from mpf.core.machine import MachineController
from mpf.core.mode import Mode
from mpf.core.player import Player


class ModeDevice(Device, metaclass=abc.ABCMeta):

    """A device in a mode."""

    __slots__ = ["mode"]

    def __init__(self, machine: MachineController, name: str) -> None:
        """Initialise mode device."""
        super().__init__(machine, name)
        self.mode = None    # type: Mode

    @asyncio.coroutine
    def device_added_to_mode(self, mode: Mode) -> Generator[int, None, None]:
        """Add device to a running mode.

        Args:
            mode: Mode which loaded the device
        """
        del mode
        yield from self._initialize()

    def device_loaded_in_mode(self, mode: Mode, player: Player) -> None:
        """Load device in running mode.

        The mode just started.

        Args:
            mode: Mode which loaded the device
            player: Current active player
        """
        del player
        self.mode = mode

    @property
    def can_exist_outside_of_game(self) -> bool:
        """Return true if this device can exist outside of a game."""
        return False

    def overload_config_in_mode(self, mode: Mode, config: dict) -> None:
        """Overload config in mode."""
        del mode
        del config
        raise AssertionError("Device {} cannot be overloaded.".format(self))

    def enable(self, **kwarg) -> None:
        """Enable handler."""
        pass

    def add_control_events_in_mode(self, mode: Mode) -> None:
        """Add control events in mode if this device has any mode control events.

        Args:
            mode: Mode which loaded the device
        """
        if "enable_events" in self.config and not self.config['enable_events']:
            mode.add_mode_event_handler("mode_{}_started".format(mode.name),
                                        self.enable, priority=100)

    def remove_control_events_in_mode(self) -> None:
        """Remove control events."""
        pass

    def device_removed_from_mode(self, mode: Mode) -> None:
        """Remove device because mode is unloading.

        Device object will continue to exist and may be added to the mode again later.

        Args:
            mode: Mode which stopped
        """
        del mode
        self.mode = None

==> mpf-0.52.10-cp34-none-any.whl: mpf/core/mode_device.py <==
"""Contains a class to implement mode devices."""
import abc
import asyncio

from typing import Generator

from mpf.core.device import Device
from mpf.core.machine import MachineController
from mpf.core.mode import Mode
from mpf.core.player import Player


class ModeDevice(Device, metaclass=abc.ABCMeta):

    """A device in a mode."""

    __slots__ = ["mode"]

    def __init__(self, machine: MachineController, name: str) -> None:
        """Initialise mode device."""
        super().__init__(machine, name)
        self.mode = None    # type: Mode

    @asyncio.coroutine
    def device_added_to_mode(self, mode: Mode) -> Generator[int, None, None]:
        """Add device to a running mode.

        Args:
            mode: Mode which loaded the device
        """
        del mode
        yield from self._initialize()

    def device_loaded_in_mode(self, mode: Mode, player: Player) -> None:
        """Load device in running mode.

        The mode just started.

        Args:
            mode: Mode which loaded the device
            player: Current active player
        """
        del player
        self.mode = mode

    @property
    def can_exist_outside_of_game(self) -> bool:
        """Return true if this device can exist outside of a game."""
        return False

    def overload_config_in_mode(self, mode: Mode, config: dict) -> None:
        """Overload config in mode."""
        del mode
        del config
        raise AssertionError("Device {} cannot be overloaded.".format(self))

    def enable(self, **kwargs) -> None:
        """Enable handler."""
        pass

    def add_control_events_in_mode(self, mode: Mode) -> None:
        """Add control events in mode if this device has any mode control events.

        Args:
            mode: Mode which loaded the device
        """
        if "enable_events" in self.config and not self.config['enable_events']:
            mode.add_mode_event_handler("mode_{}_started".format(mode.name),
                                        self.enable, priority=100)

    def remove_control_events_in_mode(self) -> None:
        """Remove control events."""
        pass

    def device_removed_from_mode(self, mode: Mode) -> None:
        """Remove device because mode is unloading.

        Device object will continue to exist and may be added to the mode again later.

        Args:
            mode: Mode which stopped
        """
        del mode
        self.mode = None
